# Contributing

Help your fellow contributors out by...

- Follow the PEP8 style guide (run `flake8` or another linter to see how you're doing)
- Try to include a docstring, at least a single line, in any function, method, or class
- Bonus points for adding a doctest as part of your contribution.
- If you add a new feature, write some quick docs in the README.
- Add your name and attribution to the AUTHORS file.
- Know we are grateful for your contribution to making the chatbot world a little better.
